@@ -34,6 +34,7 @@ CATEGORY_MAP = {
     "artstation"     : "ArtStation",
     "aryion"         : "Eka's Portal",
     "atfbooru"       : "ATFBooru",
+    "atfforum"       : "All The Fallen",
     "azurlanewiki"   : "Azur Lane Wiki",
     "b4k"            : "arch.b4k.dev",
     "baraag"         : "baraag",
@@ -43,6 +44,7 @@ CATEGORY_MAP = {
     "cfake"          : "Celebrity Fakes",
     "cien"           : "Ci-en",
     "cohost"         : "cohost!",
+    "comedywildlifephoto": "Comedy Wildlife Photography Awards",
     "comicvine"      : "Comic Vine",
     "cyberfile"      : "CyberFile",
     "dankefuerslesen": "Danke fürs Lesen",
@@ -205,6 +207,7 @@ CATEGORY_MAP = {
     "webmshare"      : "webmshare",
     "webtoons"       : "WEBTOON",
     "weebcentral"    : "Weeb Central",
+    "weebdex"        : "WeebDex",
     "wikiart"        : "WikiArt.org",
     "wikigg"         : "wiki.gg",
     "wikimediacommons": "Wikimedia Commons",
@@ -340,6 +343,9 @@ SUBCATEGORY_MAP = {
         "discord-server": "",
         "posts"         : "",
     },
+    "koofr": {
+        "shared": "Shared Links",
+    },
     "leakgallery": {
         "trending" : "Trending Medias",
         "mostliked": "Most Liked Posts",
