@@ -6,7 +6,6 @@
 
 from gallery_dl.extractor import imgur
 from gallery_dl import exception
-import datetime
 
 
 __tests__ = (
@@ -215,7 +214,7 @@ __tests__ = (
     },
     "account_id" : 0,
     "count"      : 19,
-    "date"       : datetime.datetime,
+    "date"       : "type:datetime",
     "description": "",
     "ext"        : "jpg",
     "has_sound"  : False,
