@@ -5,7 +5,6 @@
 # published by the Free Software Foundation.
 
 from gallery_dl.extractor import picarto
-import datetime
 
 
 __tests__ = (
@@ -16,7 +15,7 @@ __tests__ = (
     "#pattern" : r"https://images\.picarto\.tv/gallery/\d/\d\d/\d+/artwork/[0-9a-f-]+/large-[0-9a-f]+\.(jpg|png|gif)",
     "#count"   : ">= 7",
 
-    "date": datetime.datetime,
+    "date": "type:datetime",
 },
 
 )
