@@ -13,8 +13,13 @@ __tests__ = (
     "#category": ("imagehost", "pixhost", "image"),
     "#class"   : imagehosts.PixhostImageExtractor,
     "#sha1_url"     : "4e5470dcf6513944773044d40d883221bbc46cff",
-    "#sha1_metadata": "3bad6d59db42a5ebbd7842c2307e1c3ebd35e6b0",
     "#sha1_content" : "0c8768055e4e20e7c7259608b67799171b691140",
+
+    "filename" : "130327671_test-",
+    "extension": "png",
+    "directory": "190",
+    "token"    : "130327671",
+    "post_url" : "https://pixhost.to/show/190/130327671_test-.png",
 },
 
 {
